package org.jeecg.modules.adweb.materialcollect.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.jeecgframework.poi.excel.annotation.Excel;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @Description: adweb_material_product
 * @Author: chenpeiqing
 * @Date:   2024-09-27
 * @Version: V1.0
 */
@Data
@TableName("adweb_material_product")
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@Schema(description="adweb_material_product")
public class AdwebMaterialProduct implements Serializable {
    private static final long serialVersionUID = 1L;

	/**id*/
	@TableId(type = IdType.AUTO)
    @Schema(description = "id")
    private Integer id;
	/**对应站点code*/
	@Excel(name = "对应站点code", width = 15)
    @Schema(description = "对应站点code")
    private String siteCode;
	/**分类id*/
	@Excel(name = "分类id", width = 15)
    @Schema(description = "分类id")
    private String categoryId;
    /**分类名称*/
    @Excel(name = "分类名称", width = 15)
    @Schema(description = "分类名称")
    private String categoryName;
	/**产品标题*/
	@Excel(name = "产品标题", width = 15)
    @Schema(description = "产品标题")
    private String productTitle;
	/**产品图片*/
	@Excel(name = "产品图片", width = 15)
    @Schema(description = "产品图片")
    private String productImage;
    /**产品视频*/
    @Excel(name = "产品视频", width = 15)
    @Schema(description = "产品视频")
    private String productVideo;
	/**产品相关词*/
	@Excel(name = "产品相关词", width = 15)
    @Schema(description = "产品相关词")
    private String prudctRelatedWords;
	/**产品简述*/
	@Excel(name = "产品简述", width = 15)
    @Schema(description = "产品简述")
    private String productSketch;
	/**产品详情*/
	@Excel(name = "产品详情", width = 15)
    @Schema(description = "产品详情")
    private String productDetail;
    /**最高重复度*/
    @Excel(name = "最高重复度", width = 15)
    @Schema(description = "最高重复度")
    private BigDecimal maximumRepeatability;
    /**重复产品Id*/
    @Excel(name = "重复产品Id", width = 15)
    @Schema(description = "重复产品Id")
    private String repeatProductId;
	/**产品状态（0：可用；1：已删除）*/
	@Excel(name = "产品状态（0：可用；1：已删除；2草稿箱）", width = 15)
    @Schema(description = "产品状态（0：可用；1：已删除；2草稿箱）")
    private Integer status;
	/**createTime*/
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern="yyyy-MM-dd")
    @Schema(description = "createTime")
    private Date createTime;

    /**置顶 排序默认为0）**/
    @Excel(name = "置顶（0为不置顶 数值越大越靠前） ", width = 15)
    @Schema(description = "置顶排序默认为0")
    private Integer topOrder;

    @TableField(exist = false)
    private String idStr;

    /**商品对应的commerceId*/
    @Schema(description = "商品对应的commerceId")
    private Integer commerceId;

    @TableField(exist = false)
    private int seqNumber;

    /**
     * 同步状态（0：未同步；1：已同步）
     */
    private Integer syncStatus;

    /**
     * 用户id
     */
    private String userId;

    /**
     * 用户名
     */
    private String userName;

    /**
     * 同步失败原因
     */
    private String syncFailReason;

    /**
     * 产品图片状态
     */
    private Integer productImageStatus;

    /**
     * 负责人的userId，如果所有人可见，则存ALL
     */
    private String principalUid;

    /**
     * 是否可编辑，用来让前台判断，当前人是否拥有此产品的编辑权限，0则表示只可查看，1表示可以编辑
     */
    @TableField(exist = false)
    private int editable;

    /**
     * 本地化产品详情的状态，0未处理，1处理中，2已成功处理，3不需要处理
     */
    private Integer localizeStatus;

    /**
     * 本地化错误次数，每次编辑后，会清零。
     */
    private Integer localizeErrorNum;

    /**
     * 网页链接
     */
    private String permalink;

    /**
     * uri
     */
    private String slug;

    /**
     * 更新时间
     */
    @JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm")
    private Date editTime;

    /**
     * wp站点产品id
     */
    private Integer wpProductId;

    /**
     * 产品id集合
     */
    @TableField(exist = false)
    private List<Integer> ids;

    /**
     * 产品对应的子站点产品id
     */
    private String subSiteProduct;
}
