package org.jeecg.modules.adweb.materialcollect.mapper;


import com.baomidou.mybatisplus.core.mapper.Mapper;
import org.apache.ibatis.annotations.Param;
import org.jeecg.modules.adweb.materialcollect.dto.AdwebMaterialCheckDTO;
import org.jeecg.modules.adweb.materialcollect.entity.AdwebMaterialCheck;
import org.jeecg.modules.adweb.materialcollect.entity.AdwebMaterialItem;

import java.util.List;

/**
 * 物料收集公共mapper
 *
 * @Author jerry
 * @Date 2022/03/31
 */

public interface MaterialCommonMapper extends Mapper {
    /**
     * 根据站点code、物料code（material_code）
     * @param materialCode
     * @param siteCode
     * @return
     */
    List<AdwebMaterialItem> selectMaterialItemList(@Param("siteCode") String siteCode,
                                                   @Param("materialCode") String materialCode);



    /**
     * 企业logo
     * @param siteCode
     * @return
     */
    String enterpriseLogo(@Param("siteCode") String siteCode);


    /**
     * 根据站点code查询此站点对应SEO套餐的id，如果绑定的套餐类型不是SEO，仍然会返回空
     *
     * @param siteCode 站点code
     * @return 套餐id
     */
    String getPlanIdBySiteCode(@Param("siteCode") String siteCode);


    /**
     * 根据套餐id获取此套餐下的检测标准
     * @param planId
     * @return
     */
    List<AdwebMaterialCheck> getRulesByPlanId(@Param("planId") String planId);

    /**
     * 根据站点code和物料code确定此物料数量
     * @param siteCode
     * @param materialCode
     * @return
     */
    int getTotalCountBySiteCodeAndMaterialCode(@Param("siteCode") String siteCode,@Param("materialCode") String materialCode);

    /**
     * 根据站点code和物料code获取产品或内容分类数量
     * @param siteCode
     * @param categoryDiff
     * @return
     */
    int getCategoryCount(@Param("siteCode") String siteCode,@Param("categoryDiff") Integer categoryDiff);

    /**
     * 根据站点code和物料code获取产品或内容分类数量
     * @param siteCode
     * @return
     */
    int getProductCount(@Param("siteCode") String siteCode);

    /**
     * 根据站点code和物料code获取产品或内容分类数量
     * @param siteCode
     * @return
     */
    int getNewsCount(@Param("siteCode") String siteCode);

    /**
     * 根据站点code和物料code获取产品或内容分类数量
     * @param siteCode
     * @return
     */
    int getDocumentCount(@Param("siteCode") String siteCode);

    /**
     * 根据站点code和物料code获取产品或内容分类数量
     * @param siteCode
     * @return
     */
    int getProductFaqCount(@Param("siteCode") String siteCode);

    List<AdwebMaterialCheckDTO> getCheckListBySiteIdList(List<Integer> siteIdList);
}
