package org.jeecg.modules.adweb.materialcollect.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.util.RedisUtil;
import org.jeecg.modules.adweb.materialcollect.dto.AdwebMaterialCheckDTO;
import org.jeecg.modules.adweb.materialcollect.dto.ProductCompletionStatus;
import org.jeecg.modules.adweb.materialcollect.entity.AdwebMaterialCheck;
import org.jeecg.modules.adweb.materialcollect.mapper.AdwebMaterialCheckMapper;
import org.jeecg.modules.adweb.materialcollect.mapper.MaterialCommonMapper;
import org.jeecg.modules.adweb.materialcollect.service.IAdwebMaterialCheckService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import java.util.List;

/**
 * @Description: adweb_material_check
 * @Author: jeecg-boot
 * @Date:   2022-05-05
 * @Version: V1.0
 */
@Slf4j
@Service
public class AdwebMaterialCheckServiceImpl extends ServiceImpl<AdwebMaterialCheckMapper, AdwebMaterialCheck> implements IAdwebMaterialCheckService {

    @Resource
    private MaterialCommonMapper materialCommonMapper;

    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private RestTemplate restTemplate;

    @Override
    public ProductCompletionStatus materialStatistics(List<AdwebMaterialCheck> materialCheckList, String siteCode) {
        return null;
    }

    /**
     * 获得当前站点下物料数量
     *
     * @param siteCode 站点
     * @param adwebMaterialCheck 检测指标
     * @return 物料数量
     */
    public int getCountByMaterialCode(String siteCode, AdwebMaterialCheck adwebMaterialCheck) {
        int count = 0;
        switch (adwebMaterialCheck.getMaterialCode()) {
            case "baseInfo":
            case "enterpriseIntroduction":
            case "projectApplication":
            case "advantage":
            case "honoraryQualification":
            case "enterpriseHistory":
            case "factoryEnvironment":
            case "serviceGuarantee":
            case "frequentQuestion":
            case "socialMediaLink":
                count = materialCommonMapper.getTotalCountBySiteCodeAndMaterialCode(siteCode, adwebMaterialCheck.getMaterialCode());
                break;
            case "productCategory":
                count = materialCommonMapper.getCategoryCount(siteCode, 0);
                break;
            case "newsCategory":
                count = materialCommonMapper.getCategoryCount(siteCode, 1);
                break;
            case "product":
                count = materialCommonMapper.getProductCount(siteCode);
                break;
            case "news":
                count = materialCommonMapper.getNewsCount(siteCode);
                break;
            case "document":
                count = materialCommonMapper.getDocumentCount(siteCode);
                break;
            case "productFaq":
                count = materialCommonMapper.getProductFaqCount(siteCode);
                break;
            default:
                break;
        }
        return count;
    }

    @Override
    public List<AdwebMaterialCheckDTO> getCheckListBySiteIdList(List<Integer> siteIdList) {
        return this.materialCommonMapper.getCheckListBySiteIdList(siteIdList);
    }

    @Override
    public String checkSiteStatus(String siteCode) {
        return "";
    }

    @Override
    public Integer getEnterpriseHistoryNum(String siteCode) {
        return 0;
    }
}
